@@ -77,7 +77,12 @@ extern "C" {
                                        *     If this option is not present, a resolution of 10^-6 is assumed
                                        *     (i.e. timestamps have the same resolution of the standard 'libpcap' timestamps).
                                        */
-#define OPT_IDB_TZONE          10    /**< XXX: if_tzone    Time zone for GMT support (TODO: specify better). */
+#define OPT_IDB_TZONE          10    /**< Time zone for GMT support.  This option has neer been specified in
+                                       *     greater detail and, unless it were to identify something such as
+                                       *     an IANA time zone database timezone, would be insufficient for
+                                       *     converting between UTC and local time.  Therefore, it SHOULD NOT
+                                       *     be used; instead, the if_iana_tzname option SHOULD be used if
+                                       *     time zone information is to be specified. */
 #define OPT_IDB_FILTER         11    /**< The filter (e.g. "capture only TCP traffic") used to capture traffic.
                                        *     The first byte of the Option Data keeps a code of the filter used
                                        *     (e.g. if this is a libpcap string, or BPF bytecode, and more).
@@ -98,13 +103,15 @@ extern "C" {
                                        *     For link layers whose FCS length can change during time,
                                        *     the Packet Block Flags Word can be used (see Appendix A (Packet Block Flags Word))
                                        */
-#define OPT_IDB_TSOFFSET       14    /**< XXX: A 64 bits integer value that specifies an offset (in seconds)
+#define OPT_IDB_TSOFFSET       14    /**< A 64-bit signed integer value that specifies an offset (in seconds)
                                        *     that must be added to the timestamp of each packet to obtain
-                                       *     the absolute timestamp of a packet. If the option is missing,
-                                       *     the timestamps stored in the packet must be considered absolute
-                                       *     timestamps. The time zone of the offset can be specified with the
-                                       *     option if_tzone. TODO: won't a if_tsoffset_low for fractional
-                                       *     second offsets be useful for highly synchronized capture systems?
+                                       *     the absolute timestamp of a packet. If the option is not present,
+                                       *     an offst of 0 is assumed (i.e., timestamps in blocks are absolute
+                                       *     timestamps).
+                                       *
+                                       *     This offset is not intended to be used as an offset between local
+                                       *     time and UTC; for this purpose, the if_iana_tzname option SHOULD be
+                                       *     used to specify a timezone.
                                        */
 #define OPT_IDB_HARDWARE       15    /**< A UTF-8 string containing the description
                                        *     of the hardware of the device used
@@ -282,7 +289,10 @@ typedef enum {
     WTAP_OPTTYPE_IPv6,
     WTAP_OPTTYPE_CUSTOM,
     WTAP_OPTTYPE_IF_FILTER,
-    WTAP_OPTTYPE_PACKET_VERDICT
+    WTAP_OPTTYPE_PACKET_VERDICT,
+    WTAP_OPTTYPE_INT8,
+    WTAP_OPTTYPE_INT32,
+    WTAP_OPTTYPE_INT64,
 } wtap_opttype_e;
 
 typedef enum {
@@ -385,6 +395,9 @@ typedef union {
     guint8 uint8val;
     guint32 uint32val;
     guint64 uint64val;
+    gint8 int8val;
+    gint32 int32val;
+    gint64 int64val;
     ws_in4_addr ipv4val;    /* network byte order */
     ws_in6_addr ipv6val;
     char *stringval;
@@ -697,6 +710,105 @@ wtap_block_set_uint64_option_value(wtap_block_t block, guint option_id, guint64
 WS_DLL_PUBLIC wtap_opttype_return_val
 wtap_block_get_uint64_option_value(wtap_block_t block, guint option_id, guint64* value) G_GNUC_WARN_UNUSED_RESULT;
 
+/** Add INT8 option value to a block
+ *
+ * @param[in] block Block to which to add the option
+ * @param[in] option_id Identifier value for option
+ * @param[in] value Value of option
+ * @return wtap_opttype_return_val - WTAP_OPTTYPE_SUCCESS if successful,
+ * error code otherwise
+ */
+WS_DLL_PUBLIC wtap_opttype_return_val
+wtap_block_add_int8_option(wtap_block_t block, guint option_id, gint8 value);
+
+/** Set INT8 option value in a block
+ *
+ * @param[in] block Block in which to set the option value
+ * @param[in] option_id Identifier value for option
+ * @param[in] value New value of option
+ * @return wtap_opttype_return_val - WTAP_OPTTYPE_SUCCESS if successful,
+ * error code otherwise
+ */
+WS_DLL_PUBLIC wtap_opttype_return_val
+wtap_block_set_int8_option_value(wtap_block_t block, guint option_id, gint8 value);
+
+/** Get INT8 option value from a block
+ *
+ * @param[in] block Block from which to get the option value
+ * @param[in] option_id Identifier value for option
+ * @param[out] value Returned value of option
+ * @return wtap_opttype_return_val - WTAP_OPTTYPE_SUCCESS if successful,
+ * error code otherwise
+ */
+WS_DLL_PUBLIC wtap_opttype_return_val
+wtap_block_get_int8_option_value(wtap_block_t block, guint option_id, gint8* value) G_GNUC_WARN_UNUSED_RESULT;
+
+/** Add INT32 option value to a block
+ *
+ * @param[in] block Block to which to add the option
+ * @param[in] option_id Identifier value for option
+ * @param[in] value Value of option
+ * @return wtap_opttype_return_val - WTAP_OPTTYPE_SUCCESS if successful,
+ * error code otherwise
+ */
+WS_DLL_PUBLIC wtap_opttype_return_val
+wtap_block_add_int32_option(wtap_block_t block, guint option_id, gint32 value);
+
+/** Set INT32 option value in a block
+ *
+ * @param[in] block Block in which to set the option value
+ * @param[in] option_id Identifier value for option
+ * @param[in] value New value of option
+ * @return wtap_opttype_return_val - WTAP_OPTTYPE_SUCCESS if successful,
+ * error code otherwise
+ */
+WS_DLL_PUBLIC wtap_opttype_return_val
+wtap_block_set_int32_option_value(wtap_block_t block, guint option_id, gint32 value);
+
+/** Get INT32 option value from a block
+ *
+ * @param[in] block Block from which to get the option value
+ * @param[in] option_id Identifier value for option
+ * @param[out] value Returned value of option
+ * @return wtap_opttype_return_val - WTAP_OPTTYPE_SUCCESS if successful,
+ * error code otherwise
+ */
+WS_DLL_PUBLIC wtap_opttype_return_val
+wtap_block_get_int32_option_value(wtap_block_t block, guint option_id, gint32* value) G_GNUC_WARN_UNUSED_RESULT;
+
+/** Add INT64 option value to a block
+ *
+ * @param[in] block Block to which to add the option
+ * @param[in] option_id Identifier value for option
+ * @param[in] value Value of option
+ * @return wtap_opttype_return_val - WTAP_OPTTYPE_SUCCESS if successful,
+ * error code otherwise
+ */
+WS_DLL_PUBLIC wtap_opttype_return_val
+wtap_block_add_int64_option(wtap_block_t block, guint option_id, gint64 value);
+
+/** Set INT64 option value in a block
+ *
+ * @param[in] block Block in which to set the option value
+ * @param[in] option_id Identifier value for option
+ * @param[in] value New value of option
+ * @return wtap_opttype_return_val - WTAP_OPTTYPE_SUCCESS if successful,
+ * error code otherwise
+ */
+WS_DLL_PUBLIC wtap_opttype_return_val
+wtap_block_set_int64_option_value(wtap_block_t block, guint option_id, gint64 value);
+
+/** Get INT64 option value from a block
+ *
+ * @param[in] block Block from which to get the option value
+ * @param[in] option_id Identifier value for option
+ * @param[out] value Returned value of option
+ * @return wtap_opttype_return_val - WTAP_OPTTYPE_SUCCESS if successful,
+ * error code otherwise
+ */
+WS_DLL_PUBLIC wtap_opttype_return_val
+wtap_block_get_int64_option_value(wtap_block_t block, guint option_id, gint64* value) G_GNUC_WARN_UNUSED_RESULT;
+
 /** Add IPv4 address option value to a block
  *
  * @param[in] block Block to which to add the option
